"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_record_1 = require("../records/ad.record");
const db_1 = require("../utils/db");
const defaultObj = {
    name: 'Test Name',
    description: 'blah',
    url: 'http://example.com',
    price: 0,
    lat: 9,
    lon: 9,
};
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
test('AdRecord.getOne returns one ad from database for one entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('abc');
    expect(ad).toBeDefined();
    expect(ad instanceof ad_record_1.AdRecord).toBeTruthy();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('testName');
}));
test('AdRecord.getOne returns null from database for not existing entry.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('asdasd');
    expect(ad).toBe(null);
}));
test('AdRecord.findAll returns array of found entries.', () => __awaiter(void 0, void 0, void 0, function* () {
    const adsArray = yield ad_record_1.AdRecord.findAll();
    expect(adsArray).toBeDefined();
    adsArray.forEach((ad) => {
        expect(ad).toHaveProperty('id');
        expect(ad).toHaveProperty('lat');
        expect(ad).toHaveProperty('lon');
    });
    expect(adsArray).not.toHaveLength(0);
}));
test('AdRecord.findAll returns array of found entries when searching for "a".', () => __awaiter(void 0, void 0, void 0, function* () {
    const adsArray = yield ad_record_1.AdRecord.findAll('a');
    expect(adsArray).toBeDefined();
    adsArray.forEach((ad) => {
        expect(ad).toHaveProperty('id');
        expect(ad).toHaveProperty('lat');
        expect(ad).toHaveProperty('lon');
    });
    expect(adsArray).not.toHaveLength(0);
}));
test('AdRecord.findAll returns empty array when searching for something that not exist.', () => __awaiter(void 0, void 0, void 0, function* () {
    const adsArray = yield ad_record_1.AdRecord.findAll('----------------------------');
    expect(adsArray).toEqual([]);
    expect(adsArray).toHaveLength(0);
}));
test('AdRecord.findAll returns smaller amount of data.', () => __awaiter(void 0, void 0, void 0, function* () {
    const adsArray = yield ad_record_1.AdRecord.findAll('');
    expect(adsArray).toBeDefined();
    adsArray.forEach((ad) => {
        expect(ad).toHaveProperty('id');
        expect(ad).toHaveProperty('lat');
        expect(ad).toHaveProperty('lon');
        expect(ad).not.toHaveProperty('price');
        expect(ad).not.toHaveProperty('description');
    });
    expect(adsArray).not.toHaveLength(0);
}));
test('AdRecord.insert returns UUID.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
}));
test('AdRecord.insert returns data to database.', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    const foundAd = yield ad_record_1.AdRecord.getOne(ad.id);
    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);
}));
//# sourceMappingURL=ad.test.js.map