import {AdRecord} from "../records/ad.record";

const defaultObj = {
    name: 'Test Name',
    description: 'blah',
    url: 'http://example.com',
    price: 0,
    lat: 9,
    lon: 9,
};

test('Can build AdRecord', () => {
    const ad = new AdRecord(defaultObj);
    expect(ad.name).toBe('Test Name');
    expect(ad.description).toBe('blah');
    expect(ad.price).toBe(0);
    expect(ad.url).toBe('http://example.com');
    expect(ad.lat).toBe(9);
    expect(ad.lon).toBe(9);
});

test('Validates invalid name', () => {
    expect(() => new AdRecord({
        ...defaultObj,
        name: null,
    })).toThrow('Nazwa ogłoszenia nie może być pusta, ani przekraczać 100 znaków.');

    expect(() => new AdRecord({
        ...defaultObj,
        name: 'a'.repeat(101),
    })).toThrow('Nazwa ogłoszenia nie może być pusta, ani przekraczać 100 znaków.');
});

test('Validates invalid description', () => {
    expect(() => new AdRecord({
        ...defaultObj,
        description: 'a'.repeat(1001),
    })).toThrow('Treść ogłoszenia nie może przekraczać 1000 znaków.');
});

test('Validates invalid price', () => {
    expect(() => new AdRecord({
        ...defaultObj,
        price: -3,
    })).toThrow('Cena nie może być mniejsza niż 0 lub większa niż 9 999 999.');

    expect(() => new AdRecord({
        ...defaultObj,
        price: 19999999,
    })).toThrow('Cena nie może być mniejsza niż 0 lub większa niż 9 999 999.');
});

test('Validates invalid url', () => {
    expect(() => new AdRecord({
        ...defaultObj,
        url: null,
    })).toThrow('Link ogłoszenia nie może być pusty, ani przekraczać 100 znaków.');

    expect(() => new AdRecord({
        ...defaultObj,
        url: 'a'.repeat(101),
    })).toThrow('Link ogłoszenia nie może być pusty, ani przekraczać 100 znaków.');

    expect(() => new AdRecord({
        ...defaultObj,
        url: 'asdasd',
    })).toThrow('Link ogłoszenia jest niepoprawny.');
});
