import {AdRecord} from "../records/ad.record";
import {pool} from "../utils/db";

const defaultObj = {
    name: 'Test Name',
    description: 'blah',
    url: 'http://example.com',
    price: 0,
    lat: 9,
    lon: 9,
};

afterAll(async () => {
    await pool.end();
});

test('AdRecord.getOne returns one ad from database for one entry.', async () => {
    const ad = await AdRecord.getOne('abc');
    expect(ad).toBeDefined();
    expect(ad instanceof AdRecord).toBeTruthy();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('testName');
});

test('AdRecord.getOne returns null from database for not existing entry.', async () => {
    const ad = await AdRecord.getOne('asdasd');
    expect(ad).toBe(null);
});

test('AdRecord.findAll returns array of found entries.', async () => {
    const adsArray = await AdRecord.findAll();
    expect(adsArray).toBeDefined();
    adsArray.forEach((ad) => {
        expect(ad).toHaveProperty('id');
        expect(ad).toHaveProperty('lat');
        expect(ad).toHaveProperty('lon');
    });
    expect(adsArray).not.toHaveLength(0);
});

test('AdRecord.findAll returns array of found entries when searching for "a".', async () => {
    const adsArray = await AdRecord.findAll('a');
    expect(adsArray).toBeDefined();
    adsArray.forEach((ad) => {
        expect(ad).toHaveProperty('id');
        expect(ad).toHaveProperty('lat');
        expect(ad).toHaveProperty('lon');
    });
    expect(adsArray).not.toHaveLength(0);
});

test('AdRecord.findAll returns empty array when searching for something that not exist.', async () => {
    const adsArray = await AdRecord.findAll('----------------------------');
    expect(adsArray).toEqual([]);
    expect(adsArray).toHaveLength(0);
});

test('AdRecord.findAll returns smaller amount of data.', async () => {
    const adsArray = await AdRecord.findAll('');
    expect(adsArray).toBeDefined();
    adsArray.forEach((ad) => {
        expect(ad).toHaveProperty('id');
        expect(ad).toHaveProperty('lat');
        expect(ad).toHaveProperty('lon');
        expect(ad).not.toHaveProperty('price');
        expect(ad).not.toHaveProperty('description');
    });
    expect(adsArray).not.toHaveLength(0);
});

test('AdRecord.insert returns UUID.', async () => {
    const ad = new AdRecord(defaultObj);

    await ad.insert();

    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');

});

test('AdRecord.insert returns data to database.', async () => {

    const ad = new AdRecord(defaultObj);
    await ad.insert();

    const foundAd = await AdRecord.getOne(ad.id);

    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);


});